from distutils.core import setup

setup(
     
     name = 'sxq',
     version = '1.0.0',
     py_modules = ['sxq'],
     author = 'sxq',
     author_email = '356834208@qq.com',
     url = 'www.helloworld.com',
     description = 'A simple printer of list',
     )



""" This is sxq.py model,and it support a function called print_lol.
    This function can deel with list"""

def print_lol(the_list):
    """ Input a list. Recursively output a lsit in screen """
    for each_item in the_list:
        if(isinstance(each_item,list)):
                print_lol(each_item)
        else:
                print each_item
